@@ -1,10 +1,10 @@
 /*
  * addrinfo.c - converts names to network addresses
- * $Id: addrinfo.c 483 2007-08-08 15:09:36Z remi $
+ * $Id: addrinfo.c 528 2007-11-03 12:26:47Z remi $
  */
 
 /*************************************************************************
- *  Copyright © 2002-2006 Rémi Denis-Courmont.                           *
+ *  Copyright © 2002-2007 Rémi Denis-Courmont.                           *
  *  This program is free software: you can redistribute and/or modify    *
  *  it under the terms of the GNU General Public License as published by *
  *  the Free Software Foundation, versions 2 or 3 of the license.        *
@@ -147,15 +147,15 @@ static int quick_usage (const char *path)
 
 static int version (void)
 {
-        printf (_("addrinfo %s (%s)\n"), VERSION, "$Rev: 483 $");
+        printf (_("addrinfo %s (%s)\n"), VERSION, "$Rev: 528 $");
 	printf (_(" built %s on %s\n"), __DATE__, PACKAGE_BUILD_HOSTNAME);
         printf (_("Configured with: %s\n"), PACKAGE_CONFIGURE_INVOCATION);
         puts (_("Written by Remi Denis-Courmont\n"));
 
-        printf (_("Copyright (C) %u-%u Remi Denis-Courmont\n"
-"This is free software; see the source for copying conditions.\n"
-"There is NO warranty; not even for MERCHANTABILITY or\n"
-"FITNESS FOR A PARTICULAR PURPOSE.\n"), 2002, 2006);
+        printf (_("Copyright (C) %u-%u Remi Denis-Courmont\n"), 2002, 2007);
+	puts (_("This is free software; see the source for copying conditions.\n"
+	        "There is NO warranty; not even for MERCHANTABILITY or\n"
+	        "FITNESS FOR A PARTICULAR PURPOSE.\n"));
         return 0;
 }
 
