@@ -1,6 +1,6 @@
 /*
  * ndisc.c - ICMPv6 neighbour discovery command line tool
- * $Id: ndisc.c 528 2007-11-03 12:26:47Z remi $
+ * $Id: ndisc.c 620 2008-04-24 20:33:56Z remi $
  */
 
 /*************************************************************************
@@ -108,10 +108,12 @@ getipv6byname (const char *name, const char *ifname, int numeric,
 
 
 static inline int
-setmcasthoplimit (int fd, int value)
+sethoplimit (int fd, int value)
 {
-	return setsockopt (fd, IPPROTO_IPV6, IPV6_MULTICAST_HOPS,
-	                   &value, sizeof (value));
+	return (setsockopt (fd, IPPROTO_IPV6, IPV6_MULTICAST_HOPS,
+	                    &value, sizeof (value))
+	     || setsockopt (fd, IPPROTO_IPV6, IPV6_UNICAST_HOPS,
+	                    &value, sizeof (value))) ? -1 : 0;
 }
 
 
@@ -667,7 +669,7 @@ ndisc (const char *name, const char *ifname, unsigned flags, unsigned retry,
 	setsockopt (fd, SOL_SOCKET, SO_DONTROUTE, &(int){ 1 }, sizeof (int));
 
 	/* sets Hop-by-hop limit to 255 */
-	setmcasthoplimit (fd, 255);
+	sethoplimit (fd, 255);
 	setsockopt (fd, IPPROTO_IPV6, IPV6_RECVHOPLIMIT,
 	            &(int){ 1 }, sizeof (int));
 
@@ -767,7 +769,7 @@ static int
 version (void)
 {
 	printf (_(
-"ndisc6: IPv6 Neighbor/Router Discovery userland tool %s (%s)\n"), VERSION, "$Rev: 528 $");
+"ndisc6: IPv6 Neighbor/Router Discovery userland tool %s (%s)\n"), VERSION, "$Rev: 620 $");
 	printf (_(" built %s on %s\n"), __DATE__, PACKAGE_BUILD_HOSTNAME);
 
 	printf (_("Configured with: %s\n"), PACKAGE_CONFIGURE_INVOCATION);
